main

Function main 

pub(crate) fn main() -> Result<(), Box<dyn Error>>
The main just parses command line args and drives the lexer, parser, and AST validator.

Arguments

  • input Single positional argument that dictates the .ani Anillo file to parse
  • –verbose Enables in-progress printing of the AST as it is being built as well as other useful information as the compiler runs (such as the initial token buffer produced by the lexer)
  • -h or –help Prints command line help